import "Turbine";
import "Turbine.Debug";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Utils.BitOps";

OptionsWindow = class(Turbine.UI.Lotro.Window);

function OptionsWindow:Constructor(parent)
	Turbine.UI.Lotro.Window.Constructor( self );
   
   --  add a check to see if we load completely
   self.loaded = false;
    
   -- set size of window	
	self.width = 500;
	self.height = 500;
	self.windowWidth, self.windowHeight = Turbine.UI.Display:GetSize();
	
	-- create array of labels and check boxes
	self.mainWindow = parent;
   
	-- set the default window settings
	self:SetPosition(self.windowWidth /2 - self.width/2,self.windowHeight/2 - self.height/2);	
	self:SetSize( self.width, self.height );
	self:SetBlendMode(Turbine.UI.BlendMode.Undefined);
	self:SetBackColor( Turbine.UI.Color(0.0,0,0,0) );
	self:SetText( optionsTitleString );
	self:SetOpacity( 1 );
	
	-- add the option items
   
   self:AddGeneralItems();
	self:SetVisible(true);
	
	-- have the main window close the options
   self.VisibleChanged = function(sender,args)
      if(self:IsVisible() == false) then
         if(parent ~= nil) then
            parent:CloseOptions();
         end
      end
   end

   
   self.loaded = true;	
end

function OptionsWindow:GetLoaded()
   return self.loaded;
end

-- function to add items to the general tab
function OptionsWindow:AddGeneralItems()

   -- label for the horizontal option
   self.HorizontalLabel = Turbine.UI.Label();
   self.HorizontalLabel:SetSize(300,20);
   self.HorizontalLabel:SetPosition(20,40);
   self.HorizontalLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.HorizontalLabel:SetParent(self);
   self.HorizontalLabel:SetText(horizontalString);
   self.HorizontalLabel:SetVisible(true);
   
   -- checkbox for horizontal option
   self.HorizontalCheck = Turbine.UI.Lotro.CheckBox();   
   self.HorizontalCheck:SetSize(19,19);
   self.HorizontalCheck:SetPosition(450,40);
   self.HorizontalCheck:SetChecked(settings.horizontal == 1);
   self.HorizontalCheck:SetParent(self);
   self.HorizontalCheck:SetVisible(true);
   
   -- label for the focus color selection
   self.FocusColorLabel = Turbine.UI.Label();
   self.FocusColorLabel:SetSize(300,20);
   self.FocusColorLabel:SetPosition(20,72);
   self.FocusColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FocusColorLabel:SetParent(self);
   self.FocusColorLabel:SetText(focusColorString);
   self.FocusColorLabel:SetVisible(true);
   
   -- 'box' for the focus color selection
   self.FocusColorBox = Turbine.UI.Label();
   self.FocusColorBox:SetSize(50,20);
   self.FocusColorBox:SetPosition(420,70);
   self.FocusColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FocusColorBox:SetParent(self);
   self.FocusColorBox:SetBackColor(settings.focusColor);
   self.FocusColorBox:SetZOrder(100);
   self.FocusColorBox:SetVisible(true);    
   
   -- label for the back color selection
   self.BackColorLabel = Turbine.UI.Label();
   self.BackColorLabel:SetSize(300,20);
   self.BackColorLabel:SetPosition(20,102);
   self.BackColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.BackColorLabel:SetParent(self);
   self.BackColorLabel:SetText(backColorString);
   self.BackColorLabel:SetVisible(true);
   
   -- 'box' for the back color selection
   self.BackColorBox = Turbine.UI.Label();
   self.BackColorBox:SetSize(50,20);
   self.BackColorBox:SetPosition(420,100);
   self.BackColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.BackColorBox:SetParent(self);
   self.BackColorBox:SetBackColor(settings.backColor);
   self.BackColorBox:SetVisible(true);   
    
   -- label for main window sliders
   self.SlidersLabel  = Turbine.UI.Label();
   self.SlidersLabel:SetSize(300,20);
   self.SlidersLabel:SetPosition(20,210);
   self.SlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.SlidersLabel:SetParent(self);
   self.SlidersLabel:SetText(mainSlidersString);
   self.SlidersLabel:SetVisible(true);
     
   -- main window min slider label
   self.mainMinSlidersLabel  = Turbine.UI.Label();
   self.mainMinSlidersLabel:SetSize(50,20);
   self.mainMinSlidersLabel:SetPosition(20,230);
   self.mainMinSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.mainMinSlidersLabel:SetParent(self);
   self.mainMinSlidersLabel:SetText(minString);
   self.mainMinSlidersLabel:SetVisible(true);  
   
   -- toggle button min slider		
	self.mainMinScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.mainMinScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.mainMinScrollBar:SetSize( 400, 10 );
	self.mainMinScrollBar:SetPosition ( 70, 235);	
	self.mainMinScrollBar:SetMinimum(0);
	self.mainMinScrollBar:SetMaximum(100);
	self.mainMinScrollBar:SetValue(settings.mainMinOpacity * 100);
	self.mainMinScrollBar:SetParent(self);

   -- toggle button max slider
   self.mainMaxSlidersLabel  = Turbine.UI.Label();
   self.mainMaxSlidersLabel:SetSize(50,20);
   self.mainMaxSlidersLabel:SetPosition(20,250);
   self.mainMaxSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.mainMaxSlidersLabel:SetParent(self);
   self.mainMaxSlidersLabel:SetText(maxString);
   self.mainMaxSlidersLabel:SetVisible(true); 
 
   -- toggle button max slider		
	self.mainMaxScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.mainMaxScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.mainMaxScrollBar:SetSize( 400, 10 );
	self.mainMaxScrollBar:SetPosition ( 70, 255);	
	self.mainMaxScrollBar:SetMinimum(0);
	self.mainMaxScrollBar:SetMaximum(100);
   self.mainMaxScrollBar:SetValue(settings.mainMaxOpacity * 100);
   self.mainMaxScrollBar:SetParent(self);
   
   -- set the horizontal option
   self.HorizontalCheck.CheckedChanged = function(sender,args)
      if(sender:IsChecked()) then
         settings.horizontal = 1;
      else
         settings.horizontal = 0;
      end
      self.mainWindow:UpdateLabels();
		self.mainWindow:SaveSettings();
   end
   
   -- call the picker when color box clicked
   self.FocusColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.HunterFocus.ColorPicker(self,0,settings.focusColor);    
   end
   
   self.BackColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.HunterFocus.ColorPicker(self,1,settings.backColor);    
   end
   
   -- update settings when sliders change
   self.mainMinScrollBar.ValueChanged = function(sender,args)
   
      -- check that the min opacity does not go higher than the max opacity
      if(self.mainMinScrollBar:GetValue() > self.mainMaxScrollBar:GetValue()) then
         self.mainMinScrollBar:SetValue(self.mainMaxScrollBar:GetValue());
      end
   
      -- do updates
      settings.mainMinOpacity = self.mainMinScrollBar:GetValue() / 100;
      self.mainWindow:SaveSettings();
      self.mainWindow:UpdateOpacity();
   end
   
   self.mainMaxScrollBar.ValueChanged = function(sender,args)
   
      -- check that the max opacity does not go lower than the min opacity
      if(self.mainMaxScrollBar:GetValue() < self.mainMinScrollBar:GetValue()) then
         self.mainMaxScrollBar:SetValue(self.mainMinScrollBar:GetValue());
      end
   
      -- do updates
      settings.mainMaxOpacity = self.mainMaxScrollBar:GetValue() / 100;
      self.mainWindow:SaveSettings();
      self.mainWindow:UpdateOpacity();
   end 
end

function OptionsWindow:setFocusColor(newColor)

    settings.focusColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);
    
end

function OptionsWindow:setBackColor(newColor)

    settings.backColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);
    
end

function OptionsWindow:CloseColorPicker()

   self.colorSelect = nil;
   self.FocusColorBox:SetBackColor(settings.focusColor);
   self.BackColorBox:SetBackColor(settings.backColor);
   self.mainWindow:SaveSettings();
   self.mainWindow:UpdateLabels();
end

